sqltriples.Subject

Module sqltriples :: Class Subject |
[show private | hide private]
[frames | no frames]

## Class Subject

A class representing a more conveniently accessible subject.

Method Summary
| ``__init__`(self, store, subject)` Initialise the subject instance with the given 'store' and 'subject' identifier.
| `__delitem__(self, predicate)`
| `__getitem__(self, predicate)`
| `__setitem__(self, predicate, object)`
| ``get_query`(self, index, constraints)` Produce for 'index' something like this:
| ``get_subquery`(self, parent_index, index)` Produce for 'index' something like this: exists (select ...
| `keys(self)`
| `values(self)`

Method Details

### __init__(self, store, subject) (Constructor) Initialise the subject instance with the given 'store' and 'subject' identifier.

### get_query(self, index, constraints=None) Produce for 'index' something like this: select ... from triples as triples_i0 where ...

### get_subquery(self, parent_index, index)
    Produce for 'index' something like this:

    exists (select ... from triples as triples_i1 where ...
            and triples_i0.subject = triples_i1.subject ...)

Generated by Epydoc 2.1 on Tue Mar 21 02:02:07 2006 | http://epydoc.sf.net